==> haskell-glib-0.13.10.0-13-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glib
version:              0.13.10.0
visibility:           public
id:                   glib-0.13.10.0-DcYtA84GwCq7QVKNLCnnFf
key:                  glib-0.13.10.0-DcYtA84GwCq7QVKNLCnnFf
license:              LGPL-2.1-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.

category:             System
abi:                  308295991a5d34407130875944d3e07b
exposed:              True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/glib-0.13.10.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/glib-0.13.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glib
hs-libraries:         HSglib-0.13.10.0-DcYtA84GwCq7QVKNLCnnFf
extra-libraries:      gobject-2.0 glib-2.0
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 text-1.2.5.0
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI

haddock-interfaces:   /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html:         /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.10.0-16-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 glib
version:              0.13.10.0
visibility:           public
id:                   glib-0.13.10.0-FodPaf0J22cC284xs5vZLj
key:                  glib-0.13.10.0-FodPaf0J22cC284xs5vZLj
license:              LGPL-2.1-only
copyright:            (c) 2001-2010 The Gtk2Hs Team
maintainer:           gtk2hs-users@lists.sourceforge.net
author:               Axel Simon, Duncan Coutts
stability:            stable
homepage:             http://projects.haskell.org/gtk2hs/
synopsis:             Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.

category:             System
abi:                  125dd7856e0e1f3b510bd2a6ddb09227
exposed:              True
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils

import-dirs:          /usr/lib/ghc-9.2.8/site-local/glib-0.13.10.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/glib-0.13.10.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-glib
hs-libraries:         HSglib-0.13.10.0-FodPaf0J22cC284xs5vZLj
extra-libraries:      gobject-2.0 glib-2.0
include-dirs:
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/sysprof-6

depends:
    base-4.16.4.0 bytestring-0.11.4.0 containers-0.6.5.1 text-1.2.5.0
    utf8-string-1.0.2-AQMRv3gsvE14uh4nlO1egX

haddock-interfaces:   /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html:         /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
